GO.php
api
cli.php
config.php.example
controller
cron.php
favicon.ico
go
groupoffice
groupofficecli.php
index.php
install
language
modules
node_modules
public.php
robots.txt
vendor
version.php
views
.htaccess
config.php
tmp