<?php

$config = array (
  'file_storage_path' => '[[softdatadir]]',
  'tmpdir' => '[[softpath]]/tmp',
  'db_host' => '[[softdbhost]]',
  'db_name' => '[[softdb]]',
  'db_user' => '[[softdbuser]]',
  'db_pass' => '[[softdbpass]]',
  'db_port' => '3306',
);

